var phidget22 = require('phidget22');

var SERVER_PORT = 5661;

function main() {

	if (process.argv.length != 3) {
		console.log('usage: node VoltageRatioInput.js <server address>');
		process.exit(1);
	}
	var hostname = process.argv[2];

	console.log('connecting to:' + hostname);
	var conn = new phidget22.Connection(SERVER_PORT, hostname, { name: 'Server Connection', passwd: '' });
	conn.connect()
		.then(runExample)
		.catch(function (err) {
			console.error('Error running example:', err.message);
			process.exit(1);
		});
}

function runExample() {

	var ch = new phidget22.VoltageRatioInput();

	ch.onAttach = function (ch) {
		console.log(ch + ' attached');
		if (ch.getDeviceID() == phidget22.DeviceID.PN_1046) {
			ch.setBridgeGain(phidget22.BridgeGain.GAIN_128X);
			ch.setBridgeEnabled(true);
		}
		
		ch.setDataInterval(500).catch(function (err) {
			console.log('failed to set data interval: ' + err.message);
		});
	};

	ch.onDetach = function (ch) {
		console.log(ch + ' detached');
	};

	ch.onError = function (code, msg) {
		console.log('Error event: ' + msg);
	};

	/* Uncomment the following lines to connect to a hub port */
	//ch.setHubPort(0);
	//ch.setIsHubPortDevice(true);	/* open the VINT hub port */

	ch.onVoltageRatioChange = function (ratio) {
		console.log('voltage ratio change:' + ratio + ' (' + this.getVoltageRatio() + ')');
	};

	/* unit[unit|name|symbol] */
	ch.onSensorChange = function (value, unit) {
		console.log('voltage ratio sensor change:' + value + unit.symbol);
	};

	ch.open().then(function (ch) {
		console.log('channel open');
		/*
		 * This is a good place to set the sensor type, or enable a bridge.
		 */
	}).catch(function (err) {
		console.log('failed to open the channel:' + err);
	});
}

if (require.main === module)
	main();
